<?php
/**
 * A debug output class for the web browser
 *
 * @author		Roland Haeder <webmaster@mxchange.org>
 * @version		0.3.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link 		http://www.mxchange.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class DebugWebOutput extends BaseFrameworkSystem implements Debugger, OutputStreamer {
	/**
	 * Private constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor
		parent::constructor(__CLASS__);

		// Set description
		$this->setObjectDescription("Debug-Ausgabe auf Konsole");

		// Create an unique ID
		$this->createUniqueID();
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$debugInstance		The prepared debug instance
	 */
	public final static function createDebugWebOutput () {
		// Get a new instance
		$debugInstance = new DebugWebOutput();

		// Return it
		return $debugInstance;
	}

	/**
	 * Outputs the given data directly
	 *
	 * @param		$output	The HTML output
	 * @return	void
	 */
	public final function outputStream ($output) {
		trigger_error($output);
	}

	/**
	 * Assigns a variable for output
	 *
	 * @param		$var		The variable we shall assign
	 * @param		$value	The value to store in the variable
	 * @return	void
	 */
	public final function assignVariable ($var, $value) {
		// Empty stub!
		trigger_error(__METHOD__.": Stub!");
	}

	/**
	 * Output the code
	 *
	 * @return	void
	 */
	public final function output ($outStream=false) {
		// Empty output will be silently ignored
		if ($outStream !== false) {
			$this->outputStream($outStream);
		}
	}
}

// [EOF]
?>
